# coding: utf-8

"""
    InductivaWebAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class TaskOperationName(str, Enum):
    """
    TaskOperationName
    """
    """
    allowed enum values
    """
    EXEC_COMMAND = 'exec_command'
    DOWNLOAD_CONTAINER = 'download_container'
    DOWNLOAD_INPUT = 'download_input'
    UNCOMPRESS_INPUT = 'uncompress_input'
    COMPRESS_OUTPUT = 'compress_output'
    UPLOAD_OUTPUT = 'upload_output'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of TaskOperationName from a JSON string"""
        return cls(json.loads(json_str))
