# coding: utf-8

"""
    InductivaWebAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self


class TaskRunnerRegisterInfo(BaseModel):
    """
    Info for creating a task-runner.
    """

  # noqa: E501
    machine_group_id: StrictStr
    create_time: datetime
    cpu_count_logical: StrictInt
    cpu_count_physical: StrictInt
    memory: StrictInt
    mpi_cluster: Optional[StrictBool] = False
    host_name: StrictStr
    host_id: StrictStr
    __properties: ClassVar[List[str]] = [
        "machine_group_id", "create_time", "cpu_count_logical",
        "cpu_count_physical", "memory", "mpi_cluster", "host_name", "host_id"
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TaskRunnerRegisterInfo from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TaskRunnerRegisterInfo from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "machine_group_id":
                obj.get("machine_group_id"),
            "create_time":
                obj.get("create_time"),
            "cpu_count_logical":
                obj.get("cpu_count_logical"),
            "cpu_count_physical":
                obj.get("cpu_count_physical"),
            "memory":
                obj.get("memory"),
            "mpi_cluster":
                obj.get("mpi_cluster")
                if obj.get("mpi_cluster") is not None else False,
            "host_name":
                obj.get("host_name"),
            "host_id":
                obj.get("host_id")
        })
        return _obj
